---
title: mcp_config
sidebarTitle: mcp_config
---

# `fastmcp.utilities.mcp_config`

## Functions

### `composite_server_from_mcp_config` <sup><a href="https://github.com/jlowin/fastmcp/blob/main/src/fastmcp/utilities/mcp_config.py#L5" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
composite_server_from_mcp_config(config: MCPConfig, name_as_prefix: bool = True) -> FastMCP
```


A utility function to create a composite server from an MCPConfig.


### `mount_mcp_config_into_server` <sup><a href="https://github.com/jlowin/fastmcp/blob/main/src/fastmcp/utilities/mcp_config.py#L16" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
mount_mcp_config_into_server(config: MCPConfig, server: FastMCP, name_as_prefix: bool = True) -> None
```


A utility function to mount the servers from an MCPConfig into a FastMCP server.

